package com.flyer.foster.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.flyer.foster.dto.*;
import com.flyer.foster.service.ICartoonService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 漫画
 *
 * @author flyer
 * @since 2024-05-25
 */
@RestController
@RequestMapping("/admin/cartoon")
public class CartoonController {
    @Autowired
    private ICartoonService iCartoonService;

    /**
     * 漫画列表-分页
     *
     * @return
     */
    @GetMapping("/list/{current}/{size}")
    public R getPageList(@PathVariable Integer current, @PathVariable Integer size, CartoonQueryDTO queryDTO) {
        return R.ok().result(iCartoonService.getPageList(new Page<>(current, size), queryDTO));
    }

    /**
     * 新增漫画
     */
    @PostMapping("")
    public R addCartoon(@Valid @RequestBody CartoonAddDTO addDTO) {
        return R.ok().result(iCartoonService.addCartoon(addDTO));
    }

    /**
     * 修改漫画
     *
     * @return
     */
    @PutMapping("/{cartoonId}")
    public R updateCartoon(@PathVariable Integer cartoonId, @RequestBody CartoonUpdateDTO updateDTO) {
        updateDTO.setId(cartoonId);
        return R.ok().result(iCartoonService.updateCartoon(updateDTO));
    }

    /**
     * 删除漫画
     *
     * @return
     */
    @PostMapping("/delete")
    public R deleteArea(@RequestBody List<Integer> idList) {
        return R.ok().result(iCartoonService.deleteByIdList(idList));
    }
}
