package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.flyer.foster.dto.RoleAddDTO;
import com.flyer.foster.dto.RoleUpdateDTO;
import com.flyer.foster.service.IRoleService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 角色
 *
 * @author flyer
 * @since 2024-05-06
 */
@RestController
@RequestMapping("/admin/role")
public class RoleController {
    @Autowired
    private IRoleService iRoleService;

    /**
     * 角色列表查看
     */
    @GetMapping("/list")
    public R getRoleList() {
        return R.ok().result(iRoleService.getRoleList());
    }

    /**
     * 新增角色
     *
     * @return
     */
    @PostMapping("")
    public R addRole(@Valid @RequestBody RoleAddDTO addDTO) {
        return R.ok().result(iRoleService.addRole(addDTO));
    }

    /**
     * 修改角色
     *
     * @param roleId
     * @return
     */
    @PutMapping("/{roleId}")
    public R updateRole(@PathVariable Integer roleId, @RequestBody RoleUpdateDTO updateDTO) {
        updateDTO.setRoleId(roleId);
        return R.ok().result(iRoleService.updateRole(updateDTO));
    }

    /**
     * 删除角色
     *
     * @param roleIdList
     * @return
     */
    @PostMapping("/delete")
    public R deleteRole(@RequestBody List<Integer> roleIdList) {
        return R.ok().result(iRoleService.deleteRole(roleIdList));
    }

    /**
     * 角色下拉框
     *
     * @return
     */
    @GetMapping("/dropdown-list")
    public R getDropdownList() {
        return R.ok().result(iRoleService.getDropdownList());
    }
}
