package com.flyer.foster.controller.app;

import com.baomidou.mybatisplus.extension.conditions.query.LambdaQueryChainWrapper;
import com.flyer.foster.consts.WechatConst;
import com.flyer.foster.dto.app.AppSubscribeRespDTO;
import com.flyer.foster.dto.app.AppUserQueryDTO;
import com.flyer.foster.entity.AppSubscribe;
import com.flyer.foster.entity.AppUser;
import com.flyer.foster.service.IAppSubscribeService;
import com.flyer.foster.service.IAppUserService;
import com.flyer.foster.util.WeChatApiUtil;
import com.flyer.foster.util.WxAccessToken;
import com.flyer.util.JwtUtil;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 小程序用户（小程序）
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/app/user")
public class AppUserController {
    @Autowired
    private JwtUtil jwtUtil;

    @Autowired
    private IAppUserService iAppUserService;

    @Autowired
    private WeChatApiUtil weChatApiUtil;

    @Autowired
    private IAppSubscribeService iAppSubscribeService;

    @RequestMapping("/login")
    public R login(@RequestBody AppUserQueryDTO dto) {
        return R.ok().result(iAppUserService.login(dto));
    }

    /**
     * 生成飞鸟看园token
     *
     * @return
     */
    @PostMapping("/generate-birdseye-token")
    public R generateBirdseyeToken() {
        String audience = "sysuimars";
        String subject = "api";
        Map<String, Object> claims = new HashMap<>();
        claims.put("userid", 12);
        String birdseyeToken = jwtUtil.createBirdseyeToken(claims, audience, subject);
        return R.ok().result(birdseyeToken);
    }

    /**
     * 给订阅用户发送消息
     *
     * @return
     */
    @PostMapping("/send-sub-msg")
    public R sendSubscribeMessage() {
        String accessToken = weChatApiUtil.getAccessToken(WechatConst.APP_ID, WechatConst.APP_SECRET);

        // 获取已经订阅用户信息
        List<AppSubscribeRespDTO> subscribeUserInfoList = iAppSubscribeService.getSubscribeUserInfo();
        for (AppSubscribeRespDTO respDTO : subscribeUserInfoList) {
            int count = respDTO.getCount();
            // 订阅次数-1
            iAppSubscribeService
                    .lambdaUpdate()
                    .set(AppSubscribe::getCount, --count)
                    .eq(AppSubscribe::getAppUserId, respDTO.getAppUserId())
                    .update();
            // 给订阅用户发消息
            weChatApiUtil.subscribeMessage(accessToken, respDTO.getOpenId(), WechatConst.SUBSCRIBE_TEMPLATE1);
        }
        return R.ok();
    }
}
