package com.flyer.foster.service.impl;

import com.flyer.foster.dto.app.AppSubscribeRespDTO;
import com.flyer.foster.entity.AppSubscribe;
import com.flyer.foster.mapper.IAppSubscribeMapper;
import com.flyer.foster.pojo.StpAppUtil;
import com.flyer.foster.service.IAppSubscribeService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 小程序订阅用户 服务实现类
 * </p>
 *
 * @author flyer
 * @since 2024-05-17
 */
@Service
public class AppSubscribeServiceImpl extends ServiceImpl<IAppSubscribeMapper, AppSubscribe> implements IAppSubscribeService {

    @Override
    public List<AppSubscribeRespDTO> getSubscribeUserInfo() {
        return baseMapper.getSubscribeUserInfo();
    }

    @Override
    public boolean addSubscribe() {
        int tenantId = StpAppUtil.getTokenSession().getInt("tenantId");
        int appUserId = StpAppUtil.getLoginIdAsInt();
        AppSubscribe appSubscribe = this.lambdaQuery().eq(AppSubscribe::getAppUserId, appUserId).one();
        if (appSubscribe == null) {
            appSubscribe = new AppSubscribe();
            appSubscribe.setAppUserId(appUserId);
            appSubscribe.setTenantId(tenantId);
            appSubscribe.setCreatedBy("kelei");
            appSubscribe.setCreatedTime(LocalDateTime.now());
            appSubscribe.setUpdatedBy("kelei");
            appSubscribe.setUpdatedTime(LocalDateTime.now());
            return this.save(appSubscribe);
        } else {
            Integer count = appSubscribe.getCount();
            return this.lambdaUpdate()
                    .set(AppSubscribe::getCount, ++count)
                    .eq(AppSubscribe::getId, appSubscribe.getId())
                    .update();
        }
    }
}
